==> easyapi-0.7.5.5-sources.jar: cn/easyutil/easyapi/interview/dto/DoSimpleUnitDto.java <==
package cn.easyutil.easyapi.interview.dto;

import cn.easyutil.easyapi.entity.db.doc.DBModuleScriptEntity;
import cn.easyutil.easyapi.interview.entity.HttpEntity;

import java.util.List;

public class DoSimpleUnitDto extends HttpEntity {

    //接口id
    private Long interfaceId;

    //需要被保存的json
    private String saveParamsJson;

    //需要被保存的参数填写table的内容
    private String saveTableJson;

    //需要被保存的header
    private String saveHeadersJson;

    //需要被保存的外包装
    private String savePackageJson;

    //后置操作
    private List<DBModuleScriptEntity> scripts;

    public Long getInterfaceId() {
        return interfaceId;
    }

    public void setInterfaceId(Long interfaceId) {
        this.interfaceId = interfaceId;
    }

    public String getSaveParamsJson() {
        return saveParamsJson;
    }

    public void setSaveParamsJson(String saveParamsJson) {
        this.saveParamsJson = saveParamsJson;
    }

    public String getSavePackageJson() {
        return savePackageJson;
    }

    public void setSavePackageJson(String savePackageJson) {
        this.savePackageJson = savePackageJson;
    }

    public String getSaveHeadersJson() {
        return saveHeadersJson;
    }

    public void setSaveHeadersJson(String saveHeadersJson) {
        this.saveHeadersJson = saveHeadersJson;
    }

    public String getSaveTableJson() {
        return saveTableJson;
    }

    public void setSaveTableJson(String saveTableJson) {
        this.saveTableJson = saveTableJson;
    }

    public List<DBModuleScriptEntity> getScripts() {
        return scripts;
    }

    public void setScripts(List<DBModuleScriptEntity> scripts) {
        this.scripts = scripts;
    }
}

==> easyapi-0.7.6.1-sources.jar: cn/easyutil/easyapi/interview/dto/DoSimpleUnitDto.java <==
package cn.easyutil.easyapi.interview.dto;

import cn.easyutil.easyapi.entity.db.doc.DBModuleScriptEntity;
import cn.easyutil.easyapi.interview.entity.HttpEntity;

import java.util.List;

public class DoSimpleUnitDto extends HttpEntity {

    //接口id
    private Long interfaceId;

    //请求地址
    private String saveUrl;

    //需要被保存的json
    private String saveParamsJson;

    //需要被保存的参数填写table的内容
    private String saveTableJson;

    //需要被保存的header
    private String saveHeadersJson;

    //需要被保存的外包装
    private String savePackageJson;

    //需要被保存的脚本
    private String savePreScripts;

    //需要被保存的脚本
    private String savePostScripts;

    //页面请求使用的参数类型
    private Integer useStyleType;

    //后置操作
    private List<DBModuleScriptEntity> scripts;

    public Long getInterfaceId() {
        return interfaceId;
    }

    public void setInterfaceId(Long interfaceId) {
        this.interfaceId = interfaceId;
    }

    public String getSaveParamsJson() {
        return saveParamsJson;
    }

    public void setSaveParamsJson(String saveParamsJson) {
        this.saveParamsJson = saveParamsJson;
    }

    public String getSavePackageJson() {
        return savePackageJson;
    }

    public void setSavePackageJson(String savePackageJson) {
        this.savePackageJson = savePackageJson;
    }

    public String getSaveHeadersJson() {
        return saveHeadersJson;
    }

    public void setSaveHeadersJson(String saveHeadersJson) {
        this.saveHeadersJson = saveHeadersJson;
    }

    public String getSaveTableJson() {
        return saveTableJson;
    }

    public void setSaveTableJson(String saveTableJson) {
        this.saveTableJson = saveTableJson;
    }

    public List<DBModuleScriptEntity> getScripts() {
        return scripts;
    }

    public void setScripts(List<DBModuleScriptEntity> scripts) {
        this.scripts = scripts;
    }

    public String getSavePreScripts() {
        return savePreScripts;
    }

    public void setSavePreScripts(String savePreScripts) {
        this.savePreScripts = savePreScripts;
    }

    public String getSavePostScripts() {
        return savePostScripts;
    }

    public void setSavePostScripts(String savePostScripts) {
        this.savePostScripts = savePostScripts;
    }

    public Integer getUseStyleType() {
        return useStyleType;
    }

    public void setUseStyleType(Integer useStyleType) {
        this.useStyleType = useStyleType;
    }


    public String getSaveUrl() {
        return saveUrl;
    }

    public void setSaveUrl(String saveUrl) {
        this.saveUrl = saveUrl;
    }
}
